=======
History
=======

1.0b5 (2018-04-27)
------------------

- Add extra parameters to send logo urls
  [erral]


- Add an extra parameter to send the XSLT template
  [erral]


1.0b4 (2018-04-25)
------------------

- Add an extra parameter to register additional optional information into the payment service
  [erral] 


1.0b3 (2018-04-20)
------------------

- Previous was an errored relase.
  [erral]


1.0b2 (2018-04-20)
------------------

- Add a parameter to use the testing environment of the Payment service.
  [erral]


1.0b1 (2018-04-18)
------------------

* Implementation of notebook 60 payments in short format (521)
  [erral]
